@@ -22,14 +22,9 @@ from LbAPCommon import render_yaml, parse_yaml, validate_yaml
 import requests
 
 from . import cern_sso
-from .exceptions import (
-    JobNotFoundError,
-)
 from .utils import pool_xml_catalog, check_production, create_output_dir
 
-# ANA_PROD_HOST = "http://127.0.0.1:5000"
-ANA_PROD_HOST = "https://lhcb-analysis-productions.web.cern.ch/"
-ANA_PROD_WEB_URL = urlparse(ANA_PROD_HOST)[:2] + ("/dynamic/test-locally/",)
+ANA_PROD_WEB_URL = urlparse(cern_sso.ANA_PROD_HOST)[:2] + ("/dynamic/test-locally/",)
 
 
 def prepare_test(production_name, job_name):
@@ -45,7 +40,7 @@ def prepare_test(production_name, job_name):
     try:
         job_data = prod_data[job_name]
     except KeyError:
-        raise JobNotFoundError(
+        click.ClickException(
             f"Job {job_name} is not found for production {production_name}!"
         )
 
@@ -61,14 +56,9 @@ def prepare_test(production_name, job_name):
         "application_version": application_version,
         "bk_query": job_data["input"]["bk_query"],
     }
-    resp = requests.get(
-        urlunparse(ANA_PROD_WEB_URL + ("", urlencode(params), "")),
-        cookies=cern_sso.sign_in(ANA_PROD_HOST),
+    data = cern_sso.get_with_cookies(
+        urlunparse(ANA_PROD_WEB_URL + ("", urlencode(params), ""))
     )
-    if not resp.ok:
-        click.secho(resp.text, fg="red")
-        raise click.ClickException("Network request for metadata failed")
-    data = resp.json()
 
     if job_data["automatically_configure"]:
         config_fn = job_name + "_autoconf.py"
@@ -121,14 +111,10 @@ def prepare_reproduce(pipeline_id, production_name, job_name, test_id="latest"):
         fg="green",
     )
 
-    resp = requests.get(
-        f"{ANA_PROD_HOST}/dynamic/{pipeline_id}/{production_name}/{job_name}/{test_id}/reproduce_locally.json",
-        cookies=cern_sso.sign_in(ANA_PROD_HOST),
+    data = cern_sso.get_with_cookies(
+        f"{cern_sso.ANA_PROD_HOST}/dynamic/{pipeline_id}/{production_name}/"
+        f"{job_name}/{test_id}/reproduce_locally.json"
     )
-    if not resp.ok:
-        click.secho(resp.text, fg="red")
-        raise click.ClickException("Network request for reproduce_locally.json failed")
-    data = resp.json()
 
     tmp_dir = tempfile.mkdtemp()
 
@@ -165,11 +151,6 @@ def prepare_reproduce(pipeline_id, production_name, job_name, test_id="latest"):
                 shutil.copyfileobj(resp.raw, fp)
 
     env_cmd = data["env-command"]
-    # TODO: This is a temporary hack
-    if "AnalysisProductions.v999999999999" not in env_cmd:
-        env_cmd = (
-            env_cmd[:1] + ["--use=AnalysisProductions.v999999999999"] + env_cmd[1:]
-        )
     return out_dir, env_cmd, data["command"]
 
 
